@@ -336,7 +336,7 @@ class ReposConf(object):
         conffn = pathJoin(self.prefix, self.conffile)
         skip_reps = {x[0] for x in self.get_calculate_repositories()}
         skip_reps.add("gentoo")
-        for conffile in glob.glob("%s/*" % confdir):
+        for conffile in glob.glob("%s/*.conf" % confdir):
             if conffile == conffn:
                 continue
             config = ConfigParser(strict=False)
