@@ -826,7 +826,8 @@ class VariableOsPython(ReadonlyVariable):
         if pythons:
             for python in pythons:
                 libpath = self.get_usrlib()
-                if path.exists(pathJoin(chroot_path, libpath, python)):
+                if (path.exists(pathJoin(chroot_path, libpath, python)) and
+                    path.exists(pathJoin(chroot_path, "usr/bin", python))):
                     return python
         for atom in sorted(
             getInstalledAtom("dev-lang/python",prefix=chroot_path),
